

proc sort data=complex.cert out=cert;
 by name;
run;

title;
footnote;
options nodate nonumber;
ods noproctitle;
ods listing;

** Define macro program to generate compute statement for each of;
** the course variables -- because each column has to be formatted;
** differently, depending on the "group" that the course belongs to.;
%macro compblk(colvar=,bck=,hilite=no, svar=, sval=);
  compute &colvar;

   if ord le 20 then do;
       call define (_col_,'FORMAT', '$1.');
       %if &hilite = y %then %do;
            if &svar..sum = &sval then 
               call define(_col_,'STYLE',"STYLE={background=&bck just=c}");

            else if mod(ord,2) = 0 then 
                 call define (_col_,'STYLE', 'STYLE={background=#eeeeee just=c}');

       %end;
       %else %if &hilite=no %then %do;
            if mod(ord,2) = 0 then 
                 call define (_col_,'STYLE', 'STYLE={background=#eeeeee just=c}');
       %end;
    end;
    else if ord in (21,22) then do;
       call define (_col_,'FORMAT', '$3.');
       call define (_col_,'STYLE',"style={background=black foreground=white just=r}");
    end;
    else if ord = 23 then do;
       call define (_col_,'FORMAT', '$botrow.');
       call define (_col_,'STYLE',"style={background=&bck foreground=black font_weight=bold}");
    end;
  endcomp;
%mend compblk;

proc format;
  value $botrow
   '1' = 'S~nB~nI~nF~nA~nS~nT'
   '2' = 'L~nW~nS~nB~nI~nO~nV~n1'  
   '3' = 'S~nB~nI~nO~nV~nR'  
   '4' = 'S~nB~nI~nO~nV~nR~n1' 
   '5' = 'S~nB~nI~nA~nM~nO'  
   '6' = 'S~nB~nI~nW~nR~nS'  
   '7' = 'S~nB~nI~nI~nD~nP'  
   '8' = 'S~nB~nI~nD~nA~nS~nH'  
   '9' = 'S~nB~nI~nJ~nM~nP'  
   '10' = 'S~nB~nI~nS~nP'  
   '11' = 'S~nB~nI~nI~nM~nS'  
   '12' = 'S~nB~nI~nO~nL~nA~nP'  
   '13' = 'S~nB~nI~nA~nO~nL~nA~nP'  
   '14' = 'L~nW~nS~nB~nI~nP~nA~nC'  
   '15' = 'L~nW~nS~nB~nI~nW~nA~nC'  
   '16' = 'S~nB~nI~nA~nD~nS'  
   '17' = 'L~nW~nS~nB~nI~nP~nR~nT'  
   '18' = 'S~nB~nI~nT~nO~nU~nR'  
   '19' = 'S~nB~nI~nV~nT~nO~nU~nR'  
   '20'  = 'P~nX~nB~nI~nF~nT';

run;


data cert_final(keep= ord name butot batot adtot trtot
               sbifast lwsbiov1 sbiovr sbiovr1 sbiamo sbiwrs sbiidp
               sbidash sbijmp sbisp sbiims sbiolap sbiaolap 
               lwsbipac lwsbiwac
               sbiads lwsbiprt
               sbitour sbivtour pxbift );
                 
  length sbifast lwsbiov1 sbiovr sbiovr1 sbiamo sbiwrs sbiidp
         sbidash sbijmp sbisp sbiims sbiolap sbiaolap 
         lwsbipac lwsbiwac
         sbiads lwsbiprt sbitour sbivtour pxbift $5;

  set cert end=eof;
  array totc nsbifast nlwsbiov1 nsbiovr nsbiovr1 nsbiamo nsbiwrs nsbiidp
               nsbidash nsbijmp nsbisp nsbiims nsbiolap nsbiaolap nlwsbipac nlwsbiwac
               nsbiads nlwsbiprt
               nsbitour nsbivtour npxbift;

  array totp psbifast plwsbiov1 psbiovr psbiovr1 psbiamo psbiwrs psbiidp
               psbidash psbijmp psbisp psbiims psbiolap psbiaolap plwsbipac nlwsbiwac
               nsbiads nlwsbiprt
               psbitour psbivtour ppxbift;

  array chr $ sbifast lwsbiov1 sbiovr sbiovr1 sbiamo sbiwrs sbiidp
               sbidash sbijmp sbisp sbiims sbiolap sbiaolap lwsbipac lwsbiwac
               sbiads lwsbiprt
               sbitour sbivtour pxbift;

  ord = _n_;
  butot = 0;
  batot = 0;
  adtot = 0;
  trtot = 0;

if _n_ = 1 then do;
  do i = 1 to dim(chr);
    totc(i) = 0;
    totp(i) = 0;
  end;
end;

do i = 1 to dim(chr);
  if chr(i) = 'C' then totc(i) + 1;
  else if chr(i) = 'P' then totp(i) + 1;
  
  if chr(i) in ('C', 'P') then do;
    if i in (5,6,7) then do;
      butot + 1;
    end;
    else if i in (8, 9, 10,11,12,13,14,15) then do;
      batot + 1;
    end;
    else if i in (16, 17) then do;
      adtot + 1;
    end;
    else if i in (18, 19,20) then do;
      trtot + 1;
    end;
  end;

end;

output;

if eof then do;
   ord = ord + 1;
   name='Now Certified';
   do i = 1 to dim(chr);
     chr(i) = right(put(totc(i),3.0));
   end;
   output;

   ord = ord + 1;
   name='In Process';
   do i = 1 to dim(chr);
     chr(i) = right(put(totp(i),3.0));
   end;
   output;

   ord = ord + 1;
   name='BotRow';
   do i = 1 to dim(chr);
     chr(i) = left(put(i,2.0));
   end;
   output;
end;
run;

options nocenter ls=225;
proc print data=cert_final;
  title 'Proc Print of "massaged" Data set';
  var ord name butot batot adtot trtot
               sbifast lwsbiov1 sbiovr sbiovr1 sbiamo sbiwrs sbiidp
               sbidash sbijmp sbisp sbiims sbiolap sbiaolap lwsbipac lwsbiwac
               sbiads lwsbiprt
               sbitour sbivtour pxbift ;
format name $20.;
run;

options nomprint nomlogic;
options missing = ' ' center;

ods listing close;
ods msoffice2k file='complex2_certify.html' style=sasweb;
ods rtf file='complex2_certify.rtf';
ods escapechar='~';
   
proc report data=cert_final nowd 
  style(report)={font_face=Arial font_size=8pt rules=none frame=void background=cxdddddd cellspacing=1 cellpadding=2px}
  style(column)={font_face=Arial font_size=8pt background=#cxcccccc cellwidth=.25in just=c}
  style(summary)={vjust=m}
  style(header)={vjust=b foreground=black background=cx9999cc font_face=Arial font_size=8pt};
  column ord name butot batot adtot trtot
            ('~S={}' sbiFAST LWSBIOV1 SBIOVR SBIOVR1 )   
            ('~S={background=cx99cc99}BI User Courses' 
                SBIAMO SBIWRS SBIIDP)  
            ('~S={background=orange}BI Analyst Courses' 
                SBIDASH SBIJMP SBISP
                SBIIMS SBIOLAP SBIaOLAP LWSBIPAC LWSBIWAC )   
            ('~S={background=cxffff99}BI AppDev' SBIADS LWSBIPRT)
            ('~S={background=pink}Other' SBITOUR SBIVTOUR PXBIFT); 
  title j=c 'Certification Report';

  define ord / order noprint;
  define name / order 'Instructor'
         style(column)={cellwidth=1.25in just=l};

  define butot /sum noprint ;
  define batot /sum noprint;
  define adtot/sum noprint;
  define trtot /sum noprint;

  ** only way to reliably rotate headers was to use this method;
  ** ~n is the ODS ESCAPECHAR method for putting in a line feed/CR;
  define sbifast / display 'S~nB~nI~nF~nA~nS~nT';
  define LWSBIOV1 / display 'L~nW~nS~nB~nI~nO~nV~n1' ; 
  define SBIOVR / display 'S~nB~nI~nO~nV~nR'  ;
  define SBIOVR1 / display 'S~nB~nI~nO~nV~nR~n1' ;
  define SBIAMO / display 'S~nB~nI~nA~nM~nO'  
         style(header)={background=cx99cc99};
  define SBIWRS / display 'S~nB~nI~nW~nR~nS'  
         style(header)={background=cx99cc99};
  define SBIIDP / display 'S~nB~nI~nI~nD~nP'  
         style(header)={background=cx99cc99};
  define SBIDASH / display 'S~nB~nI~nD~nA~nS~nH'  
         style(header)={background=orange};
  define SBIJMP / display 'S~nB~nI~nJ~nM~nP'  
         style(header)={background=orange};
  define SBISP  / display 'S~nB~nI~nS~nP'  
         style(header)={background=orange};
  define SBIIMS / display 'S~nB~nI~nI~nM~nS'  
         style(header)={background=orange};
  define SBIOLAP / display 'S~nB~nI~nO~nL~nA~nP'  
         style(header)={background=orange};
  define SBIAOLAP / display 'S~nB~nI~nA~nO~nL~nA~nP'  
         style(header)={background=orange};
  define LWSBIPAC / display 'L~nW~nS~nB~nI~nP~nA~nC'  
         style(header)={background=orange};
  define LWSBIWAC / display 'L~nW~nS~nB~nI~nW~nA~nC'  
         style(header)={background=orange};
  define SBIADS / display 'S~nB~nI~nA~nD~nS'  
         style(header)={background=cxffff99};
  define LWSBIPRT / display 'L~nW~nS~nB~nI~nP~nR~nT'  
         style(header)={background=cxffff99};
  define SBITOUR / display 'S~nB~nI~nT~nO~nU~nR'  
         style(header)={background=pink};
  define SBIVTOUR / display 'S~nB~nI~nV~nT~nO~nU~nR'  
         style(header)={background=pink};
  define PXBIFT  / display 'P~nX~nB~nI~nF~nT'
         style(header)={background=pink};


  compute name;
    if ord le 20 then do;
       if mod(ord,2) = 0 then 
          call define (_col_,'STYLE', 'STYLE={background=#eeeeee just=l}');
    end;
    else if ord in (21,22) then do;
          call define (_col_,'STYLE', 'STYLE={background=black foreground=white font_style=italic just=l font_weight=bold}');
    end;
    else if ord = 23 then do;
       if name = 'BotRow' then name = ' ';
       call define (_col_,'STYLE','STYLE={background=cx9999cc foreground=black vjust=t font_size=8pt}');
    end;
  endcomp;


  ** doing same calc and format for every numeric cell;
  ** so use macro snippet above;
  %compblk(colvar= sbifast, bck=cx9999cc, hilite=no);
  %compblk(colvar= LWSBIOV1, bck=cx9999cc, hilite=no); 
  %compblk(colvar= SBIOVR , bck=cx9999cc, hilite=no); 
  %compblk(colvar= SBIOVR1, bck=cx9999cc,  hilite=no); 

  %compblk(colvar= SBIAMO, bck=cx99cc99, hilite=y, svar=butot, sval=3); 
  %compblk(colvar= SBIWRS, bck=cx99cc99, hilite=y, svar=butot, sval=3); 
  %compblk(colvar= SBIIDP, bck=cx99cc99, hilite=y, svar=butot, sval=3); 

  %compblk(colvar= SBIDASH, bck=orange, hilite=y, svar=batot, sval=8); 
  %compblk(colvar= SBIJMP, bck=orange, hilite=y, svar=batot, sval=8);            
  %compblk(colvar= SBISP, bck=orange, hilite=y, svar=batot, sval=8); 
  %compblk(colvar= SBIIMS, bck=orange, hilite=y, svar=batot, sval=8); 
  %compblk(colvar= SBIOLAP , bck=orange, hilite=y, svar=batot, sval=8); 
  %compblk(colvar= SBIAOLAP, bck=orange, hilite=y, svar=batot, sval=8); 
  %compblk(colvar= LWSBIPAC, bck=orange, hilite=y, svar=batot, sval=8); 
  %compblk(colvar= LWSBIWAC, bck=orange, hilite=y, svar=batot, sval=8);  
 
  %compblk(colvar= SBIADS, bck=cxffff99, hilite=y, svar=adtot, sval=2); 
  %compblk(colvar= LWSBIPRT, bck=cxffff99, hilite=y, svar=adtot, sval=2); 

  %compblk(colvar= SBITOUR, bck=pink, hilite=y, svar=trtot, sval=3); 
  %compblk(colvar= SBIVTOUR,bck=pink, hilite=y, svar=trtot, sval=3); 
  %compblk(colvar= PXBIFT, bck=pink, hilite=y, svar=trtot, sval=3); 

run;
 
ods _all_ close;
ods listing;

