ods listing;

** 1) Order Each Region by Product Descending Sales;
proc report data=sashelp.shoes nowd 
            out=work.prodsum(keep=region product sales rpord);
  where region in ('Asia', 'Canada', 'Pacific');
  column region product sales sales=rpord;
  define region / group;
  define product / group;
  define sales / sum;
  define rpord / sum 'Region Order';
run;

options center nodate nonumber;
ods listing close;

ods html file='complex3_diff_order_by_Region.html' style=sasweb;
proc report data=prodsum nowd
  style(summary)=Header;
  title 'Each Region by Highest to Lowest Product Sales';
  title2 'Products Ordered Independently for Each Region';
  column region rpord product sales;
  define region /order;
  define rpord / order descending noprint;
  define product / order;
  define sales / sum;
  rbreak after /summarize;
  break after region / summarize;
  compute after;
    region = 'Grand Total';
  endcomp;
run;
   
ods html close;


** 2) Order Each Region by Overall Product Descending Sales Order;
proc report data=sashelp.shoes nowd 
            out=work.ovsum(keep=product ovpord);
  where region in ('Asia', 'Canada', 'Pacific');
  column product sales sales=ovpord;
  define product / group;
  define sales / sum;
  define ovpord / sum 'Overall Product Order';
run;

proc sql;
  create table difford as
    select a.region, a.product, b.ovpord, a.rpord, a.sales
    from prodsum as a,
         ovsum as b
    where a.product = b.product
    order by region, product;
quit;



ods html file='complex3_diff_order_Overall.html' style=sasweb;
proc report data=difford nowd
  style(summary)=Header;
  title 'All Products by Descending Sales';
  title2 ' ';
  column ovpord product sales;
  define ovpord /group descending noprint;
  define product / group;
  define sales/ sum;
  rbreak after/ summarize;
  compute after;
    Product = 'Grand Total';
  endcomp;
run;


proc report data=difford nowd
  style(summary)=Header;
  title 'Each Region by Overall Product Sales Order';
  title2 'Products Ordered the Same As Overall Sales Order';
  column region ovpord product sales;
  define region /group;
  define ovpord /order descending noprint;
  define product / order;
  define sales/ sum;
  break after region /summarize;
  rbreak after/ summarize;
  compute after;
    region = 'Grand Total';
  endcomp;
run;
ods html close;
