ods listing;
proc report data=sashelp.shoes nowd 
            out=work.prodsum(keep=region product sales rpord);
  where region in ('Asia', 'Canada', 'Pacific');
  column region product sales sales=rpord;
  define region / group;
  define product / group;
  define sales / sum;
  define rpord / sum 'Region Order';
run;

proc report data=sashelp.shoes nowd 
            out=work.ovsum(keep=product ovpord sales);
  where region in ('Asia', 'Canada', 'Pacific');
  column product sales sales=ovpord;
  define product / group;
  define sales / sum;
  define ovpord / sum 'Overall Product Order';
run;

proc sql;
  create table difford as
    select a.region, a.product, b.ovpord, a.rpord, a.sales
    from prodsum as a,
         ovsum as b
    where a.product = b.product
    order by region, product;
quit;

options center nodate nonumber nobyline;
ods listing close;
ods html file='complex3_diff_order_BYVAL1.html' style=sasweb;

proc report data=ovsum nowd
  style(summary)=Header;
  title 'All Regions Product Sales';
  column ovpord product sales;
  define ovpord / order descending noprint;
  define product / order;
  define sales / sum;
  rbreak after /summarize;
  compute after;
    product = 'All Regions';
  endcomp;
run;
  
proc report data=prodsum nowd
  style(summary)=Header;
  by region;
  title 'Each Region by Highest to Lowest Product Sales';
  title2 'Region: #byval(region)';
  column region rpord product sales;
  define region /order;
  define rpord / order descending noprint;
  define product / order;
  define sales / sum;
  rbreak after /summarize;
  compute after;
    region = 'Region Total';
  endcomp;
run;
  
ods html close;


ods html file='complex3_diff_order_BYVAL2.html' style=sasweb;

proc report data=ovsum nowd
  style(summary)=Header;
  title 'All Regions Product Sales';
  column ovpord product sales;
  define ovpord / order descending noprint;
  define product / order;
  define sales / sum;
  rbreak after /summarize;
  compute after;
    product = 'All Regions';
  endcomp;
run;
 
proc report data=difford nowd
  style(summary)=Header;
  by region;
  title 'Each Region Ordered Same As Overall Product Sales Order';
  title2 'Region: #byval(region)';
  column region ovpord product sales;
  define region /group;
  define ovpord /order descending noprint;
  define product / order;
  define sales/ sum;
  rbreak after/ summarize;
  compute after;
    region = 'Region Total';
  endcomp;
run;

ods html close;

title;
footnote;
options byline;
