ods listing;
title;
footnote;

%let outpath=C:\Courses\SAS_Global_Forum_2008\complex\output;
%let htout = .;

proc sort data=complex.DistrictSales out=DistrictSales;
by year district quarter;
run;

proc report data=DistrictSales nowd 
            out=work.distinfo(keep=year district quarter sales);
  column year district quarter sales;
  define year / group;
  define district / group;
  define quarter / group;
  define sales / sum;
run;

proc print data=distinfo;
title 'distinfo';
run;

ods listing;

proc report data=DistrictSales nowd 
            out=work.ovinfo(keep=year district ovsales 
                                 ovmean);
  column year district sales sales=ovmean sales=ovsales 
         sales=ovmin sales=ovmax;
  define year /group;
  define district / group;
  define sales / sum;
  define ovmean / mean 'Overall District Mean';
  define ovsales / sum 'Overall District Sales';
run;

proc print data=ovinfo;
title 'ovinfo';
run;

proc format;
  value $qnum 'Q1'='1'
              'Q2'='2'
              'Q3'='3'
              'Q4'='4';
run;

proc sql;
  create table diffrept as
    select a.year, a.district, a.quarter, a.sales, b.ovsales,
        b.ovmean,
        round(a.sales/1000000,1) as salesM
    from distinfo as a,
         ovinfo as b
    where a.year=b.year and a.district = b.district
    order by district, quarter;
quit;

ods listing;

proc print data=diffrept;
title 'diffrept data for SAS/Graph';
run;

data diffrept1(keep=rowval colval1 colval2);
    rowval = 1;
    colval1 = '1 Northern';
    colval2 = '2 Eastern';
    output;
    rowval = 2;
    colval1 = '1 Southern';
    colval2 = '2 Western';
    output;
run;
ods listing;

proc print data=diffrept1;
title 'diffrept1';
run;

proc sort data=diffrept;
by district year quarter sales ovmean;

run;


 ods listing;

**  Make some graphs ;
** delete the previous entries to ensure that the names are what;
** you want to set in the gseg catalog and/or in the file system.;

proc greplay igout = work.gseg nofs;
  delete _all_;
run;
quit;

** This ODS HTML step is used to create the graphs and get the;
** SASWEB style applied to the graphs. That is why I do not use;
** GSF file syntax. The "DUMMYGR.HTML" file can be deleted after;
** the Graph files are created.;

ods html path="&htout" (url=none)
          gpath="&htout" (url=none)
          file='dummygr.html' style=sasweb stylesheet;

 goptions reset=all hsize=5.00 vsize=3.00 device=actximg;

axis1 order=(0 to 15 by 3);

proc gchart data=diffrept;
  where district = 'Northern';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='North';
  label salesM='Northern' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;

proc gchart data=diffrept;
  where district = 'Eastern';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='East';
  label salesM='Eastern' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;
 
proc gchart data=diffrept;
  where district = 'Southern';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='South';
  label salesM='Southern' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;

proc gchart data=diffrept;
  where district = 'Western';
  by district ;
  vbar quarter/sumvar=salesM group=year raxis=axis1 name='West';
  label salesM='Western' quarter='Qtr' year='Yr';
  format quarter $qnum.;
run;
quit;

ods html close;


ods listing close;
title;
footnote;
options orientation=landscape;
 
ods html path="&htout" (url=none)
          gpath="&htout" (url=none)
          file='complex5a_smallmult.html' style=sasweb stylesheet;
ods escapechar='~';

proc report data=diffrept1 nowd center missing
  style(header)={background=pink foreground=black vjust=b};
  column rowval ('Quarterly District Sales/(in Millions)' colval1 colval2) ;
  define rowval / group 'District' 
         style(header)={just=l}
         style(column)={vjust=b} noprint;
  define colval1 / group ' ' order=internal;
  define colval2 / group ' ' order=internal;

  compute colval1;
    colval1 = scan(colval1,1,' ');
    if rowval = '1' then do;
       call define('_c2_','STYLE','style={preimage="North.png" foreground=white}');
    end;
    else if rowval = '2' then do;
       call define('_c2_','STYLE','style={preimage="South2.png" foreground=white}');
    end;
  endcomp;

  compute colval2;
    colval2 = scan(colval2,1,' ');
    if rowval = '1' then do;
       call define('_c3_','STYLE','style={preimage="East1.png" foreground=white}');
    end;
    else if rowval = '2' then do;
       call define('_c3_','STYLE','style={preimage="West3.png" foreground=white}');
    end;
  endcomp;
  run;

ods _all_ close;

** Make PDF and RTF -- they need a different location for the;
** graphic files, so could not use same code as above.;
ods listing close;
options orientation=landscape topmargin=1in bottommargin=1in
        rightmargin=1.5in leftmargin=1.5in;
ods pdf file="&outpath\complex5a_smallmult.pdf";
ods rtf file="&outpath\complex5a_smallmult.rtf";
ods escapechar='~';

proc report data=diffrept1 nowd center missing
  style(report)={outputwidth=100%}
  style(header)={background=pink foreground=black vjust=b}
  style(column)={just=c};
  column rowval ('Quarterly District Sales/(in Millions)' colval1 colval2) ;
  define rowval / group 'District' 
         style(header)={just=l}
         style(column)={vjust=b} noprint;
  define colval1 / group ' ' order=internal;
  define colval2 / group ' ' order=internal;

  compute colval1;
    colval1 = scan(colval1,1,' ');
    if rowval = '1' then do;
       call define('_c2_','STYLE','style={preimage="&outpath\North.png" foreground=white}');
    end;
    else if rowval = '2' then do;
       call define('_c2_','STYLE','style={preimage="&outpath\South2.png" foreground=white}');
    end;
  endcomp;

  compute colval2;
    colval2 = scan(colval2,1,' ');
    if rowval = '1' then do;
       call define('_c3_','STYLE','style={preimage="&outpath\East1.png" foreground=white}');
    end;
    else if rowval = '2' then do;
       call define('_c3_','STYLE','style={preimage="&outpath\West3.png" foreground=white}');
    end;
  endcomp;
  run;
ods _all_ close;
ods listing;
title;
options orientation=portrait;


