ods listing;
title;
options center;
footnote;

%let outpath=C:\Courses\SAS_Global_Forum_2008\complex\output;
%let htout = .;

proc sort data=complex.DistrictSales out=DistrictSales;
by year district quarter;
run;

ods listing;

proc report data=DistrictSales nowd 
            out=work.ovinfo(keep=year district ovsales ovmean 
                            salesmn salesmx salesavg salescnt);
  column district year sales sales=ovmean sales=ovsales
         sales=salesmn sales=salesmx sales=salesavg sales=salescnt;
  define district / group;
  define year /group;
  define sales / sum;
  define ovsales / sum 'Overall District Sales';
  define salesmn / min 'Overall District Min';
  define salesmx / max 'Overall District Max';
  define salesavg/ mean 'Overall District Avg';
  define salescnt / n 'Overall Number of Sales';
  break after district /summarize;
  rbreak after / summarize;
run;

proc print data=ovinfo;
title 'ovinfo';
run;

proc format;

  value $ovord 'Northern' = '1'
           'Eastern' = '2'
           'Southern' = '3'
           'Western' = '4'
           'ZZZZZZZZ' = '5';

  value $onpg 'Northern' = '1'
           'Eastern' = '1'
           'Southern' = '2'
           'Western' = '2'
           'ZZZZZZZZ' = '2';

** for HTML need relative name, where graph will be when VIEWED.;
  value $distimg
  'Northern' = 'North.png'
  'Eastern' = 'East1.png'
  'Southern' = 'South2.png'
  'Western' = 'West3.png';

  ** for RTF and PDF need fully qualified location of graph;
  ** when RTF and PDF files are CREATED.;
  value $drtfpdf
  'Northern' = "&outpath\North.png"
  'Eastern' = "&outpath\East1.png"
  'Southern' = "&outpath\South2.png"
  'Western' = "&outpath\West3.png";
run;

options linesize=256 center;
data bldmult(keep=onpg ovord district year1-year5 sale1-sale5
     min1-min5 max1-max5 avg1-avg5 cnt1-cnt5   
     rpt_yr rpt_sl rpt_min rpt_max rpt_avg rpt_cnt);

  length district $15 cr $2
         rpt_yr rpt_sl rpt_min rpt_max rpt_avg rpt_cnt $250;
  set ovinfo;

  if year = . then year = 9999;
  if district = ' ' then district = 'ZZZZZZZZ';

  by district notsorted;
  retain year1-year5 sale1-sale5
     min1-min5 max1-max5 avg1-avg5 cnt1-cnt5
     rpt_yr rpt_sl rpt_min rpt_max rpt_avg rpt_cnt;

  array yr year1-year5;
  array sa sale1-sale5;
  array mn min1-min5;
  array mx max1-max5;
  array av avg1-avg5;
  array cn cnt1-cnt5;
  if first.district then do;
     i = 0;
     rpt_yr = '~S={font_weight=bold background=pink }~_~_Year~_~_~S={}~n2005~n2006~n2007~n2008~nTotal~S={background=white}';
     if district = 'ZZZZZZZZ' then do;
        rpt_yr = 'All Years';
        rpt_sl = ' ';
        rpt_min = ' ';
        rpt_max = ' ';
        rpt_avg = ' ';
        rpt_cnt = ' ';
     end;
     else if district ne 'ZZZZZZZZ' then do;
     rpt_sl = '~S={font_weight=bold background=pink }~_~_~_~_Total~_~_~_~_~S={background=white}';
     rpt_min = '~S={font_weight=bold background=pink }~_~_Min~_~_~S={background=white}';
     rpt_max = '~S={font_weight=bold background=pink }~_~_Max~_~_~S={background=white}';
     rpt_avg = '~S={font_weight=bold background=pink }~_~_Avg~_~_~S={background=white}';
     rpt_cnt = '~S={font_weight=bold background=pink }~_Number~_~S={background=white}';
     end;
  end;
  i + 1;

  yr(i) = year;
  sa(i) = ovsales;
  mn(i) = salesmn;
  mx(i) = salesmx;
  av(i) = salesavg;
  cn(i) = salescnt;

  cr = '~n';
  if district = 'ZZZZZZZZ' then cr = ' ';

  rpt_sl = compbl(catt(rpt_sl,cr,put(sa(i),dollar15.)));
  rpt_min = compbl(catt(rpt_min,cr,put(mn(i),comma15.)));
  rpt_max = compbl(catt(rpt_max,cr,put(mx(i),comma15.))) ;
  rpt_avg  = compbl(catt(rpt_avg,cr,put(av(i),comma15.)));
  rpt_cnt = compbl(catt(rpt_cnt,cr,put(cn(i),comma15.)));

  if last.district then do;
     ovord = put(district,$ovord.);
     onpg = put(district,$onpg.);
     if district = 'ZZZZZZZZ' then district = 'All Districts';
     output;
  end;
run;

proc print data=bldmult;
  title 'bldmult';
run;


ods html path="&htout" (url=none)
         file="complex6a_graf_report.html" 
    style=sasweb ;
ods escapechar='~';

proc report data=bldmult nowd
  style(report)={background=white}
  style(header)={foreground=black background=pink}
  style(column)={just=right};
  title 'PROC REPORT with SAS/GRAPH Image in Table';
  column onpg ovord ('Quarterly Comparison' district) 
     ('Sales' rpt_yr rpt_sl rpt_cnt rpt_min rpt_max rpt_avg);
  define onpg /order noprint;
  define ovord /order noprint;
  define district / order 
     style(column)={just=left} ' ';
  define rpt_yr / display ' ';
  define rpt_sl /display ' ';
  define rpt_cnt /display ' ';
  define rpt_min /display ' ';
  define rpt_max /display ' ';
  define rpt_avg /display ' ';
  compute district;
    if ovord le '4' then district = ovord;
    if ovord = '1' then do;
       call define(_col_,'STYLE','style={preimage="North.png" foreground=white}');
    end;
    else if ovord = '2' then do;
       call define(_col_,'STYLE','style={preimage="East1.png" foreground=white}');
    end;
    else if ovord = '3' then do;
       call define(_col_,'STYLE','style={preimage="South2.png" foreground=white}');
    end;
    else if ovord = '4' then do;
       call define(_col_,'STYLE','style={preimage="West3.png" foreground=white}');
    end;
    else if ovord = '5' then do;
       call define(_row_,'STYLE','style=Header{background=pink foreground=black}');
    end;

  endcomp;
  break after onpg / page;
run;

ods _all_ close;

/*
** Have to get rid of background=pink for PDF and RTF;
data bldmult2;
  set bldmult;
  srchstr = "background=pink";
  if index(rpt_yr,srchstr) gt 0 then
     rpt_yr = trim(substr(rpt_yr,1,index(rpt_yr,srchstr)-1))||substr(rpt_yr,index(rpt_yr,srchstr)+15);
  if index(rpt_sl,srchstr) gt 0 then
     rpt_sl = substr(rpt_sl,1,index(rpt_sl,srchstr)-1)||substr(rpt_sl,index(rpt_sl,srchstr)+15);

  if index(rpt_min,srchstr) gt 0 then
     rpt_min = substr(rpt_min,1,index(rpt_min,srchstr)-1)||substr(rpt_min,index(rpt_min,srchstr)+15);
  if index(rpt_max,srchstr) gt 0 then
     rpt_max = substr(rpt_max,1,index(rpt_max,srchstr)-1)||substr(rpt_max,index(rpt_max,srchstr)+15);

  if index(rpt_avg,srchstr) gt 0 then
     rpt_avg = substr(rpt_avg,1,index(rpt_avg,srchstr)-1)||substr(rpt_avg,index(rpt_avg,srchstr)+15);
  if index(rpt_cnt,srchstr) gt 0 then
     rpt_cnt = substr(rpt_cnt,1,index(rpt_cnt,srchstr)-1)||substr(rpt_cnt,index(rpt_cnt,srchstr)+15);
run;
ods listing close;

options orientation=landscape center topmargin=.25in bottommargin=.25in
        leftmargin=.25in rightmargin=.25in;
 
ods pdf file="&outpath\complex6a_graf_report.pdf" ;
ods rtf file="&outpath\complex6a_graf_report.rtf" ;

ods escapechar='~';

proc report data=bldmult2 nowd
  style(header)={foreground=black}
  style(column)={just=right};
  title 'PROC REPORT with SAS/GRAPH Image for RTF and PDF';
  column onpg ovord ('Quarterly Comparison' district) 
     ('Sales' rpt_yr rpt_sl rpt_cnt rpt_min rpt_max rpt_avg);
  define onpg /order noprint;
  define ovord /order noprint;
  define district / order 
     style(column)={just=left cellwidth=5in} ' ';
  define rpt_yr / display ' ' style={vjust=m};
  define rpt_sl /display ' ' style={vjust=m};
  define rpt_cnt /display ' ' style={vjust=m};
  define rpt_min /display ' ' style={vjust=m};
  define rpt_max /display ' ' style={vjust=m};
  define rpt_avg /display ' ' style={vjust=m};
  compute district;
    if ovord le '4' then district = ovord;
    if ovord = '1' then do;
       call define(_col_,'STYLE','style={preimage="&outpath\North.png" foreground=white}');
    end;
    else if ovord = '2' then do;
       call define(_col_,'STYLE','style={preimage="&outpath\East1.png" foreground=white}');
    end;
    else if ovord = '3' then do;
       call define(_col_,'STYLE','style={preimage="&outpath\South2.png" foreground=white}');
    end;
    else if ovord = '4' then do;
       call define(_col_,'STYLE','style={preimage="&outpath\West3.png" foreground=white}');
    end;
    else if ovord = '5' then do;
       call define(_row_,'STYLE','style=Header{foreground=black}');
    end;

  endcomp;
  break after onpg / page;
run;

ods _all_  close;
*/
